/* Esercizio di ricerca in un albero binario di ricerca,
   dove il risultato della ricerca e' la profondita' del nodo. */
#include <stdio.h>
#include <stdlib.h>


/* Definizione di un nodo
   "menoSx" indica che i valori minori
   sono alla sinistra, e rappresenta
   il puntatore al nodo sinistro. Similarmente
   per piuDx. */
typedef struct _nd {
  int chiave;
  struct _nd *menoSx, *piuDx;
} nd;

/* Cerca: 
   Distinguiamo due casi:
    se x e' trovato, allora la procedura deve funzionare
    ricorsivamente su uno dei due cammini (quello
    indicato dalla releazione tra x e le chiavi dei nodi)
    Per ottenere la profondita' quindi, sommiamo
    1 ad ogni chiamata ricorsiva che facciamo
    e chiudiamo la somma con uno 0 quando lo troviamo.

    se x non e' nell'albero, allora avremo una chiamata
    con cerca(NULL, x), e ritorniamo -1.
    In questo caso dobbiamo stare attenti a non confondere
    le due modalita': se una sottochiamata ritorna -1,
    allora questo "-1" deve essere propagato piu' in alto,
    senza aggiungere alcunche'.  
*/
int cerca ( nd *nodo, int cosa ) 
{
   int v;

   /* Non trovato, facciamo partire il -1*/
   if ( nodo == NULL )  
      return -1;

   /* Trovato! Chiudiamo la catena di somme. */
   if ( cosa == nodo->chiave ) 
      return 0;

   /* Cerco nel sottoalbero giusto */
   if ( cosa < nodo->chiave)
      v = cerca ( nodo->menoSx, cosa );
   else
      v = cerca ( nodo->piuDx, cosa ); 

    /* Propaghiamo eventuali -1 */
    if ( v == -1 ) 
      return -1;
    return 1 + v;
}


/* Inserimento in un ABR. 
   Ritorna l'eventuale nuova radice. */
nd *inserisci ( nd *radice, int val ) 
{
   nd *nuovo = malloc(sizeof(nd));
   nd *p = radice;

   nuovo->chiave = val;
   nuovo->menoSx = nuovo->piuDx = NULL;

   if ( radice == NULL ) return nuovo;

   /* Scendiamo nel sottoalbero giusto finche'
      possiamo. Quando non possiamo, sappiamo
      che dobbiamo agganciare il nuovo nodo li'. */
   while ( (val < p->chiave && p->menoSx != NULL ) ||
           (val > p->chiave && p->piuDx != NULL ) )
      if ( val < p->chiave )   
        p = p->menoSx;
      else
        p = p->piuDx;

   if ( val < p->chiave ) 
      p->menoSx = nuovo; 
   else
      p->piuDx = nuovo;

   return radice;
}

int main()
{
  int i, N, val;
  nd *radice = NULL;

  scanf("%d", &N );
  
  for ( i = 0; i < N; i++ ) 
  {
    scanf("%d", &val);
    radice = inserisci ( radice, val );
  }

  while ( 1 ) {
    scanf("%d", &val);
    if ( val == -1 ) break;
    printf("%d\n", cerca( radice, val ) );
  }


  return 0;
}



